======================
Utils Module Reference
======================

The ``vascusim.utils`` module provides utilities for visualization and metadata handling.

Visualization Functions
----------------------

.. autofunction:: vascusim.utils.plot_geometry

.. autofunction:: vascusim.utils.plot_flow

.. autofunction:: vascusim.utils.plot_pressure

.. autofunction:: vascusim.utils.plot_mesh

.. autofunction:: vascusim.utils.plot_comparison

.. autofunction:: vascusim.utils.create_animation

Metadata Functions
-----------------

.. autofunction:: vascusim.utils.query_metadata

.. autofunction:: vascusim.utils.filter_by_attribute

.. autofunction:: vascusim.utils.get_unique_values

.. autofunction:: vascusim.utils.merge_metadata

.. autofunction:: vascusim.utils.find_metadata_files

.. autofunction:: vascusim.utils.index_metadata

.. autofunction:: vascusim.utils.group_by_attribute

.. autofunction:: vascusim.utils.summarize_metadata

.. autofunction:: vascusim.utils.update_metadata

Module Contents
-------------

.. automodule:: vascusim.utils
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
---------

Visualization Submodule
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: vascusim.utils.visualization
   :members:
   :undoc-members:
   :show-inheritance:

Metadata Submodule
~~~~~~~~~~~~~~~~~

.. automodule:: vascusim.utils.metadata
   :members:
   :undoc-members:
   :show-inheritance: